@@ -6,7 +6,7 @@ pdoc auto-generates API documentation that follows your project's Python module
 pdoc's main feature is a focus on simplicity: pdoc aims to do one thing and do it well.
 
  - Easy setup, no configuration necessary.
- - Documentation is plain Markdown.
+ - Documentation is plain [Markdown](#markdown-support).
  - First-class support for type annotations.
  - Builtin web server with live reloading.
  - Customizable HTML templates.
@@ -95,8 +95,9 @@ the generated documentation however you want! pdoc's job is to "just" produce se
 A very simple way to host your API documentation is to set up a continuous integration job which
 pushes your documentation to GitHub Pages. This keeps your docs updated automatically.
 
- 1. Enable GitHub Actions and GitHub Pages in your project's settings.
- 2. Copy pdoc's GitHub Actions workflow into your own repository and adjust it to how you build your docs:
+ 1. Enable GitHub Actions and GitHub Pages for your project.
+ 2. In the GitHub Pages settings, select GitHub Actions as your build and deployment source.
+ 3. Copy pdoc's GitHub Actions workflow into your own repository and adjust it to how you build your docs:
     [`.github/workflows/docs.yml`](https://github.com/mitmproxy/pdoc/blob/main/.github/workflows/docs.yml)
 
 That's it – no need to fiddle with any secrets or set up any `gh-pages` branches. 🥳
@@ -127,6 +128,7 @@ the docstring should come on the line immediately following `class
 the file. These docstrings are what you see for each module, class,
 function and method listed in the documentation produced by pdoc.
 
+
 ## ...document variables?
 
 Python itself [does not attach docstrings to
@@ -169,6 +171,7 @@ class GoldenRetriever(Dog):
     """Full Name (different for each instance)"""
 ```
 
+
 ## ...control what is documented?
 
 The public interface of a module is determined through one of two
@@ -206,6 +209,7 @@ pdoc foo !foo.bar
 Likewise, `pdoc pdoc !pdoc.` would document the pdoc module itself, but none of its submodules. Patterns are always
 matched on the final module name, even if modules are passed as file paths.
 
+
 ## ...link to other identifiers?
 
 In your documentation, you can link to other identifiers by enclosing them in backticks:
@@ -218,6 +222,7 @@ pdoc will link all identifiers that are rendered in the current run.
 This means that you need to run `pdoc module_a module_b` to have interlinking between module_a and module_b.
 If you run `pdoc module_a` followed by `pdoc module_b`, there will be no cross-linking between the two modules.
 
+
 ## ...change the item order?
 
 By default, documentation items are sorted in order of (first) appearance in the source code.
@@ -225,6 +230,7 @@ This means that if you want to move a particular function to the beginning of yo
 you need to move it there in your source code. This is not only useful to the readers of your documentation,
 but also useful to the consumers of your source code.
 
+
 ## ...use numpydoc or Google docstrings?
 
 While pdoc prefers docstrings that are plain Markdown, it also understands numpydoc and Google-style docstrings.
@@ -270,6 +276,17 @@ You can include external Markdown files in your documentation by using reStructu
 Since version 11, pdoc processes such reStructuredText elements by default.
 
 
+## ...add a title page?
+
+The landing page for your documentation is your project's top-level `<modulename>/__init__.py` file.
+Adding a module-level docstring here is a great way to introduce users to your project.
+For example, the documentation you are reading right now is sourced from
+[`pdoc/__init__.py`](https://github.com/mitmproxy/pdoc/blob/main/pdoc/__init__.py).
+You can also include your title page from a [Markdown file](#include-markdown-files).
+
+If you have multiple top-level modules, a custom title page requires modifying the `index.html.jinja2` template.
+You can find an example in [#410](https://github.com/mitmproxy/pdoc/issues/410).
+
 ## ...edit pdoc's HTML template?
 
 For more advanced customization, we can edit pdoc's
@@ -300,6 +317,7 @@ pdoc -t . ./demo.py
 See [`examples/`](https://github.com/mitmproxy/pdoc/tree/main/examples/)
 for more examples.
 
+
 ## ...pass arguments to the Jinja2 template?
 
 If you need to pass additional data to pdoc's Jinja2 templates,
@@ -379,6 +397,48 @@ code, then it will automatically attach the docstring for `Dog.bark` to
     [integrating pdoc into other systems](https://pdoc.dev/docs/pdoc.html#integrate-pdoc-into-other-systems).
 
 
+# Markdown Support
+
+[Markdown](https://guides.github.com/features/mastering-markdown/) is a lightweight and popular markup language for text
+formatting. There are many versions or *"flavors"* of Markdown.
+pdoc uses the [markdown2](https://github.com/trentm/python-markdown2) library, which closely matches
+the behavior of the original [Markdown 1.0.1 spec][].
+In addition, the following extra syntax elements are enabled:
+
+  - **[code-friendly][]:** Disable `_` and `__` for `em` and `strong`.
+  - **[cuddled-lists][]:** Allow lists to be cuddled to the preceding
+    paragraph.
+  - **[fenced-code-blocks][]:** Allows a code block to not have to be
+    indented by fencing it with <code>```</code> on a line before and after.
+    Based on [GitHub-Flavored Markdown][] with support for syntax highlighting.
+  - **[footnotes][]:** Support footnotes as in use on daringfireball.net
+    and implemented in other Markdown processors.
+  - **[header-ids][]:** Adds "id" attributes to headers. The id value
+    is a slug of the header text.
+  - **[markdown-in-html][]:** Allow the use of `markdown="1"` in a
+    block HTML tag to have markdown processing be done on its contents.
+    Similar to [PHP-Markdown Extra][] but with some limitations.
+  - **[pyshell][]:** Treats unindented Python interactive shell
+    sessions as `<code>` blocks.
+  - **strike:** Parse `~~strikethrough~~` formatting.
+  - **[tables][]:** Tables using the same format as [GitHub-Flavored Markdown][] and
+    [PHP-Markdown Extra][].
+  - **task_list:** Allows GitHub-style task lists (i.e. check boxes)
+  - **toc:** The returned HTML string gets a new "toc_html"
+    attribute which is a Table of Contents for the document.
+
+[Markdown 1.0.1 spec]: https://daringfireball.net/projects/markdown/
+[code-friendly]: https://github.com/trentm/python-markdown2/wiki/code-friendly
+[cuddled-lists]: https://github.com/trentm/python-markdown2/wiki/cuddled-lists
+[fenced-code-blocks]: https://github.com/trentm/python-markdown2/wiki/fenced-code-blocks
+[footnotes]: https://github.com/trentm/python-markdown2/wiki/footnotes
+[header-ids]: https://github.com/trentm/python-markdown2/wiki/header-ids
+[markdown-in-html]: https://github.com/trentm/python-markdown2/wiki/markdown-in-html
+[pyshell]: https://github.com/trentm/python-markdown2/wiki/pyshell
+[tables]: https://github.com/trentm/python-markdown2/wiki/tables
+[GitHub-Flavored Markdown]: https://github.github.com/gfm/
+[PHP-Markdown Extra]: https://michelf.ca/projects/php-markdown/extra/#table
+
 # Using pdoc as a library
 
 pdoc provides the high-level `pdoc.pdoc()` interface explained below. This makes it possible to do custom adjustments
@@ -390,10 +450,8 @@ You can find an example in [`examples/library-usage`](https://github.com/mitmpro
 from __future__ import annotations
 
 __docformat__ = "markdown"  # explicitly disable rST processing in the examples above.
-__version__ = "12.0.1"  # this is read from setup.py
+__version__ = "12.1.0"  # this is read from setup.py
 
-import traceback
-import warnings
 from pathlib import Path
 from typing import overload
 
@@ -443,13 +501,7 @@ def pdoc(
 
     all_modules: dict[str, doc.Module] = {}
     for module_name in extract.walk_specs(modules):
-        try:
-            all_modules[module_name] = doc.Module.from_name(module_name)
-        except RuntimeError:
-            warnings.warn(f"Error importing {module_name}:\n{traceback.format_exc()}")
-
-    if not all_modules:
-        raise RuntimeError("Unable to import any modules.")
+        all_modules[module_name] = doc.Module.from_name(module_name)
 
     for module in all_modules.values():
         if format == "html":
