@@ -42,7 +42,7 @@ from pdoc.doc_types import (
     safe_eval_type,
 )
 
-from ._compat import cache, cached_property, formatannotation, get_origin
+from ._compat import cache, cached_property, formatannotation, get_origin, singledispatchmethod
 
 
 def _include_fullname_in_traceback(f):
@@ -227,14 +227,14 @@ class Namespace(Doc[T], metaclass=ABCMeta):
     @cached_property
     @abstractmethod
     def own_members(self) -> list[Doc]:
-        """A list of all own (i.e. non-inherited) members"""
+        """A list of all own (i.e. non-inherited) `members`."""
 
     @cached_property
     def members(self) -> dict[str, Doc]:
         """A mapping from all members to their documentation objects.
 
         This mapping includes private members; they are only filtered out as part of the template logic.
-
+        Constructors for enums, dicts, and abstract base classes are not picked up unless they have a custom docstring.
         """
         members: dict[str, Doc] = {}
         for name, obj in self._member_objects.items():
@@ -246,7 +246,7 @@ class Namespace(Doc[T], metaclass=ABCMeta):
             is_property = (
                 isinstance(obj, (property, cached_property))
                 or
-                # Python 3.9: @classmethod @property is now allowed.
+                # Python 3.9 - 3.10: @classmethod @property is allowed.
                 is_classmethod
                 and isinstance(obj.__func__, (property, cached_property))
             )
@@ -473,9 +473,12 @@ class Module(Namespace[types.ModuleType]):
     def _member_objects(self) -> dict[str, Any]:
         members = {}
 
-        all = _safe_getattr(self.obj, "__all__", False)
-        if all:
-            for name in all:
+        all_: list[str] | None = _safe_getattr(self.obj, "__all__", None)
+        if all_ is not None:
+            for name in all_:
+                if not isinstance(name, str):
+                    # Gracefully handle the case where objects are directly specified in __all__.
+                    name = _safe_getattr(name, "__name__", str(name))
                 if name in self.obj.__dict__:
                     val = self.obj.__dict__[name]
                 elif name in self._var_annotations:
@@ -808,6 +811,8 @@ class Function(Doc[types.FunctionType]):
         unwrapped: types.FunctionType
         if isinstance(func, (classmethod, staticmethod)):
             unwrapped = func.__func__  # type: ignore
+        elif isinstance(func, singledispatchmethod):
+            unwrapped = func.func  # type: ignore
         else:
             unwrapped = func
         super().__init__(modulename, qualname, unwrapped, taken_from)
@@ -836,7 +841,15 @@ class Function(Doc[types.FunctionType]):
             cls = sys.modules.get(_safe_getattr(self.obj, "__module__", None), None)
             for name in _safe_getattr(self.obj, "__qualname__", "").split(".")[:-1]:
                 cls = _safe_getattr(cls, name, None)
-            doc = _safe_getdoc(_safe_getattr(cls, self.name, None))
+
+            unbound = _safe_getattr(cls, "__dict__", {}).get(self.name)
+            is_classmethod_property = isinstance(unbound, classmethod) and isinstance(
+                unbound.__func__, (property, cached_property)
+            )
+            if not is_classmethod_property:
+                # We choke on @classmethod @property, but that's okay because it's been deprecated with Python 3.11.
+                # Directly accessing them would give us the return value, which has the wrong docstring.
+                doc = _safe_getdoc(_safe_getattr(cls, self.name, None))
 
         if doc == object.__init__.__doc__:
             # inspect.getdoc(Foo.__init__) returns the docstring, for object.__init__ if left undefined...
